==> deposits_oneclick_checkout-0.0.2.tar.gz: lib/app/common/global/deposits_oneclick_checkout_controller.dart <==
import 'package:deposits_oneclick_checkout/app/common/utils/exports.dart';
import 'package:deposits_oneclick_checkout/app/model/charge_funds_source/charge_funds_response.dart';

class PayWithDepositsController extends GetxController {
  final isLoading = false.obs;
  ChargeFundResponse finalChargeFundResponse = ChargeFundResponse();
  
   payWithCard(BuildContext context, Widget initialScreen , ValueChanged<ChargeFundResponse>? chargeFundResponse)async {
    try {
    isLoading(true);
    var request = {
          'token': Storage.getValue(Constants.token),
          'api_key': Constants.apiKey,
          'sub_client_api_key': Storage.getValue(Constants.subClientApiKey),
          'amount' : Storage.getValue(Constants.amountToProcess),
          'card_id' : Storage.getValue(Constants.cardId)
        };
        var response = await DioClient().request(context: context,api:'/charge-funding-source',method:Method.POST ,params: request);
        ChargeFundResponse chargeFundResponse = ChargeFundResponse.fromJson(response) ;
        if (chargeFundResponse.status == Strings.success) {
          chargeFundResponse = chargeFundResponse;
          finalChargeFundResponse = chargeFundResponse;
          Utils.navigationPush(context, Successful(
                    successTitle: Strings.paymentSuccessful,
                    successMessage: Strings.paymentSuccessmgs,
                    initialScreen: initialScreen),
          );
          } else {
           return Utils.showSnackbar(context, Strings.error,response['message'],  AppColors.red);
         }
        } finally {
        isLoading(false);
      }
      update();
  }

   payWithBank(BuildContext context, Widget initialScreen ,ValueChanged<ChargeFundResponse>? chargeFundResponse) async {
      try {
    isLoading(true);
    var request = {
          'token': Storage.getValue(Constants.token),
          'api_key': Constants.apiKey,
          'sub_client_api_key': Storage.getValue(Constants.subClientApiKey),
          'amount' : Storage.getValue(Constants.amountToProcess),
          'account_id' : Storage.getValue(Constants.bankId)
        };
        var response = await DioClient().request(context: context,api:'/charge-funding-source',method:Method.POST ,params: request);
        ChargeFundResponse chargeFundResponse = ChargeFundResponse.fromJson(response) ;
        if (chargeFundResponse.status == Strings.success) {
          chargeFundResponse = chargeFundResponse;
          finalChargeFundResponse = chargeFundResponse;
          Utils.navigationPush(context, Successful(
                    successTitle: Strings.paymentSuccessful,
                    successMessage: Strings.paymentSuccessmgs,
                    initialScreen: initialScreen),
          );
          } else {
           return Utils.showSnackbar(context, Strings.error,response['message'],  AppColors.red);
         }
        } finally {
        isLoading(false);
      }
      update();
   }

  
}

==> deposits_oneclick_checkout-0.0.3.tar.gz: lib/app/common/global/deposits_oneclick_checkout_controller.dart <==
import 'package:deposits_oneclick_checkout/app/common/utils/exports.dart';

class PayWithDepositsController extends GetxController {
  final isLoading = false.obs;
  ChargeFundResponse finalChargeFundResponse = ChargeFundResponse();
  
   payWithCard(BuildContext context,  ValueChanged<ChargeFundResponse>? chargeFundResponse)async {
    try {
    isLoading(true);
    var visitorId = await FingerPrintJs().getVisitorId();
    var meta = {
      'ip': '',
      'fingerprint': visitorId,
      'device': 'Mobile App',
      'browser': 'Mobile App',
      'country': '',
      'city': '',
      'isp': '',
    };
    var request = {
          'token': Storage.getValue(Constants.token),
          'api_key': Constants.apiKey,
          'sub_client_api_key': Storage.getValue(Constants.subClientApiKey),
          'amount' : Storage.getValue(Constants.amountToProcess),
          'card_id' : Storage.getValue(Constants.cardId),
          'meta' : meta
        };
        print(request);
        var response = await DioClient().request(context: context,api:'/charge-funding-source',method:Method.POST ,params: request);
        if(response !=null){
        ChargeFundResponse chargeFundResponse = ChargeFundResponse.fromJson(response) ;
        if (chargeFundResponse.status == Strings.success) {
          chargeFundResponse = chargeFundResponse;
          finalChargeFundResponse = chargeFundResponse;
          Utils.navigationReplace(context, Successful(
                    successTitle: Strings.paymentSuccessful,
                    successMessage: Strings.paymentSuccessmgs),
          );
          } else {
            return Utils.showSnackbar(context, Strings.error,response['message'],  AppColors.red);
          }
        }
        } finally {
        isLoading(false);
      }
      update();
  }

   payWithBank(BuildContext context, ValueChanged<ChargeFundResponse>? chargeFundResponse) async {
      try {
    isLoading(true);
    var visitorId = await FingerPrintJs().getVisitorId();
    var meta = {
      'ip': '',
      'fingerprint': visitorId,
      'device': 'Mobile App',
      'browser': 'Mobile App',
      'country': '',
      'city': '',
      'isp': '',
    };
    var request = {
          'token': Storage.getValue(Constants.token),
          'api_key': Constants.apiKey,
          'sub_client_api_key': Storage.getValue(Constants.subClientApiKey),
          'amount' : Storage.getValue(Constants.amountToProcess),
          'account_id' : Storage.getValue(Constants.bankId),
          'meta' : meta
        };
        var response = await DioClient().request(context: context,api:'/charge-funding-source',method:Method.POST ,params: request);
        if (response != null) {
        ChargeFundResponse chargeFundResponse = ChargeFundResponse.fromJson(response) ;
        if (chargeFundResponse.status == Strings.success) {
          chargeFundResponse = chargeFundResponse;
          finalChargeFundResponse = chargeFundResponse;
          Utils.navigationReplace(context, Successful(
                    successTitle: Strings.paymentSuccessful,
                    successMessage: Strings.paymentSuccessmgs,),
          );
          } else {
           return Utils.showSnackbar(context, Strings.error,response['message'],  AppColors.red);
         }
      }
        } finally {
        isLoading(false);
      }
      update();
   }

}
